@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# Copyright (C) 2013-2014 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2013-2015 Rocky Bernstein <rocky@cpan.org>
 # Documentation is at the __END__
 use strict; use warnings;
 
@@ -18,7 +18,7 @@ use Exporter;
 
 use constant PROGRAM => 'trepan.pl';
 use version;
-$VERSION='0.58'; # To fool CPAN indexer. Is <= real version
+$VERSION='0.60'; # To fool CPAN indexer. Is <= real version
 $VERSION = $Devel::Trepan::Version::VERSION;
 $PROGRAM = PROGRAM;
 
@@ -309,10 +309,6 @@ L<Evaluate Perl code (eval)|Devel::Trepan::CmdProcessor::Command::Eval>
 
 =item *
 
-L<Recursively Debug into Perl code (debug)|Devel::Trepan::CmdProcessor::Command::Debug>
-
-=item *
-
 L<Cancel some expressions to be displayed when program stops
 (undisplay)|Devel::Trepan::CmdProcessor::Command::Undisplay>
 
@@ -324,7 +320,7 @@ L<Cancel some expressions to be displayed when program stops
 
 =item *
 
-L<Deparse source code vis B::Deparse (deparse)|Devel::Trepan::CmdProcessor::Command::Deparse>
+L<Deparse source code via B::Deparse (deparse)|Devel::Trepan::CmdProcessor::Command::Deparse>
 
 =item *
 
@@ -504,7 +500,7 @@ L<Debugger Command Examples|Devel::Trepan::CmdProcessor::Command::Help::examples
 =head1 BUGS/CAVEATS
 
 Because this should be useful in all sorts of environments such as
-back to perl 5.008, we often can make use of newer Perlisms nor can we
+back to perl 5.008, we often can not make use of newer Perlisms nor can we
 I<require> by default all of the modules, say for data printing, stack
 inspection, or interactive terminal handling. That said, if you have a
 newer Perl or the recommended modules or install plugins, you'll get
